@@ -6,14 +6,16 @@ from mt_aws_utils.dbutil import Db
 class AWSMarkThis(Db):
     '''AWS MarkThis database access layer'''
 
-    def sheet_insert(self, sheetid, title, style, answers_csv):
-        '''Insert sheet'''
+    def sheet_insert(self, rows):
+        '''Insert sheets.
+        rows is a list of tuples.  Each row has the following items in order
+        sheetid, owner, title, style, answers_csv '''
 
         qry = '''INSERT into sheet
-                 (sheetid, title, style, answers_csv, created_at)
-                 VALUES(%s, %s, %s, %s, NOW())'''
+                 (sheetid, owner, title, style, answers_csv, created_at)
+                 VALUES(%s, %s, %s, %s, %s, NOW())'''
 
-        return self.singlequery(qry, (sheetid, title, style, answers_csv))
+        return self.executemany(qry, rows)
 
     def sheet_get(self, sheetid):
         '''gets sheet info for sheetid'''
